# SupportedLanguages

Languages the application supports.

## Enum

* `NB` (value: `'nb'`)

* `NN` (value: `'nn'`)

* `EN` (value: `'en'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


